# Changelog

## 0.1 (2021-04-25)

- Initial release

## 0.1.1 (2021-04-25)

- Fixed typing errors

## 0.1.2 (2021-04-25)

- Make `Tag` base class public, add missing table related tags.

## 0.1.3 (2021-08-27)

- Renamed `Tag` base class to `Element`
